#ifndef LOCKMANAGER_H
#define LOCKMANAGER_H

#include <stdbool.h>
#include <stralloc.h>
#include <afblib/strhash.h>

typedef struct lockset {
   char* dirname;
   char* myname;
   stralloc myfile;
   strhash locks;
} lockset;

/*
 * initialize lock set
 */
bool lm_init(lockset* set, char* dirname, char* myname);

/* release all locks associated with set and allocated storage */
void lm_free(lockset* set);

/*
 * check status of the given lock and return
 * the name of the holder in holder if it's held
 * and an empty string if the lock is free
 */
bool lm_stat(lockset* set, char* lockname, stralloc* holder);

/* block until `lockname' is locked */
bool lm_lock(lockset* set, char* lockname);

/* attempt to lock `lockname' but do not block */
bool lm_nonblocking_lock(lockset* set, char* lockname);

/* release `lockname' */
bool lm_release(lockset* set, char* lockname);

#endif
